@@ -6,7 +6,8 @@ library(dplyr)
 library(codebook)
 
 ## -----------------------------------------------------------------------------
-darktriad <- rio::import("https://osf.io/j4fcb/download", format = "sav")
+darktriad_path <- system.file("extdata", "darktriad.sav", package = "codebook")
+darktriad <- rio::import(darktriad_path, format = "sav")
 if (!knit_by_pkgdown) {
   darktriad <- darktriad %>%
   select(DG, sex, relStat, education, NPI_avg)
@@ -16,8 +17,8 @@ if (!knit_by_pkgdown) {
 metadata(darktriad)$name <- "How alluring are dark personalities? The Dark Triad and attractiveness in speed dating"
 metadata(darktriad)$description <- paste0("The data to this speed dating study comes in two different formats: Personwise (one record for each individual) and dyadic (pairwise; one record for each date). The respective SPSS files are named \"DarkTriadDate_person.sav\" and \"DarkTriadDate_dyad.sav\".
 
-### Download link
-[Open Science Framework](https://osf.io/j4fcb/download)
+### Original source
+[Open Science Framework](https://osf.io/j4fcb/)
 
 ### Personwise datafile 
 The personwise datafile contains individual differences variables and perceiver and target effects according to the social relations model. These are centered marginal means that were calculated according to the formulae provided by Kenny, Kashy, and Cook (2006). These effects are not (!) based on multilevel analyses.
@@ -71,9 +72,9 @@ metadata(darktriad)$temporalCoverage <- "2015"
 metadata(darktriad)$spatialCoverage <- "Graz, Austria" 
 metadata(darktriad)$distribution = list(
   list("@type" = "DataDownload",
-       "requiresSubscription" = "http://schema.org/True",
+       "requiresSubscription" = "https://schema.org/True",
        "encodingFormat" = "https://www.loc.gov/preservation/digital/formats/fdd/fdd000469.shtml",
-       contentUrl = "https://osf.io/j4fcb/download")
+       contentUrl = "https://osf.io/download/j4fcb")
 )
 
 ## -----------------------------------------------------------------------------
@@ -93,9 +94,9 @@ meta <- recursive_escape(meta)
 
 ## ----results='asis'-----------------------------------------------------------
 if (exists("name", meta)) {
-  glue::glue(
+  glue::glue_data(
     "__Dataset name__: {name}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis'-----------------------------------------------------------
@@ -103,30 +104,30 @@ cat(description)
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("temporalCoverage", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __Temporal Coverage__: {temporalCoverage}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("spatialCoverage", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __Spatial Coverage__: {spatialCoverage}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("citation", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __Citation__: {citation}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("url", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __URL__: [{url}]({url})",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
@@ -136,22 +137,26 @@ if (exists("identifier", meta)) {
       stringr::str_match(meta$identifier, "^doi:(.+)")[,2], '">', 
       meta$identifier, '</a>')
   }
-  glue::glue(
+  glue::glue_data(
     "- __Identifier__: {identifier}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("datePublished", meta)) {
-  glue::glue(
+  glue::glue_data(
     "- __Date published__: {datePublished}",
-    .envir = meta)
+    .x = meta)
 }
 
 ## ----results='asis', echo = FALSE---------------------------------------------
 if (exists("creator", meta)) {
   cat("- __Creator__:")
-  knitr::kable(tibble::enframe(meta$creator))
+  creator <- lapply(meta$creator, function(x) {
+    if (is.list(x)) paste(names(x), x, sep = ": ", collapse = ", ")
+    else x
+  })
+  knitr::kable(tibble::enframe(creator))
 }
 
 ## -----------------------------------------------------------------------------
@@ -160,7 +165,12 @@ meta <- meta[setdiff(names(meta),
                        "url", "citation", "spatialCoverage", 
                        "temporalCoverage", "description", "name"))]
 if(length(meta)) {
-  knitr::kable(meta)
+  remaining <- lapply(meta, function(x) {
+    if (is.list(x)) paste(names(x), x, sep = ": ", collapse = ", ")
+    else if (length(x) > 1) paste(x, collapse = ", ")
+    else as.character(x)
+  })
+  knitr::kable(tibble::enframe(remaining))
 }
 
 ## ----setup,eval=TRUE,echo=FALSE-----------------------------------------------
